meansq: Function optim will minimize
Description
Computes the mean square of the time series at the point x, will be minimize with the optim function in our function estimation.
Usage
meansq(x, dim.ar = NULL, dim.ma = NULL, y)
Arguments
x
One point in \(\rm I\!R^{(p+q)}\).
Value
msMean square at the point x.